/***************************************************************************
                          job_appendcdromtodatabase.h  -  description
                             -------------------
    begin                : Thu May 31 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_APPENDCDROMTODATABASE_H
#define JOB_APPENDCDROMTODATABASE_H

#include "prokyon.h"

#include "jobbasetagmanipulation.h"

#include "lvi_cddrive.h"

class Job_AppendCDROMToDatabase : public JobBaseTagManipulation  {
public:
    Job_AppendCDROMToDatabase(LVI_CDDrive *_drive);

    int type() {
        return JOB_APPEND_CDROM_TO_DATABASE;
    }

    void run();

    ~Job_AppendCDROMToDatabase();

private:
    LVI_CDDrive *drive;
};

#endif
